@@ -3,11 +3,15 @@
 HttpCtrl library provides HTTP/HTTPS client and server API to Robot Framework to make REST API testing easy.
 
 Authors: Andrei Novikov
-Date: 2018-2021
+Date: 2018-2022
 Copyright: The 3-Clause BSD License
 
 """
 
+
+from HttpCtrl.utils.logger import LoggerAssistant
+
+
 class Request:
     def __init__(self, host, port, method, url, headers, body=None):
         self.__source_host = host
@@ -21,7 +25,8 @@ class Request:
         return Request(self.__source_host, self.__source_port, self.__method, self.__url, self.__headers, self.__body)
 
     def __str__(self):
-        return "%s %s\n%s" % (self.__method, self.__url, self.__body)
+        body_to_log = LoggerAssistant.get_body(self.__body)
+        return "%s %s\n%s" % (self.__method, self.__url, body_to_log)
 
     def get_source_address(self):
         return self.__source_host
